@@ -22,11 +22,10 @@
 #include <kacceleratormanager.h>
 #include <kcolorbutton.h>
 #include <klineedit.h>
-#include <kinputdialog.h>
 #include <KLocalizedString>
-#include <knuminput.h>
 
 #include <QCheckBox>
+#include <QDoubleSpinBox>
 #include <QGroupBox>
 #include <QHeaderView>
 #include <QLabel>
@@ -34,6 +33,7 @@
 #include <QTreeView>
 #include <QGridLayout>
 #include <QBitmap>
+#include <QInputDialog>
 #include "DancingBarsSettings.h"
 
 DancingBarsSettings::DancingBarsSettings( QWidget* parent, const char* name )
@@ -179,7 +179,8 @@ DancingBarsSettings::DancingBarsSettings( QWidget* parent, const char* name )
   label = new QLabel( i18n( "Font size:" ), page );
   pageLayout->addWidget( label, 3, 0 );
 
-  mFontSize = new KIntNumInput( 9, page );
+  mFontSize = new QSpinBox( page );
+  mFontSize->setValue( 9 );
   mFontSize->setWhatsThis( i18n( "This determines the size of the font used to print a label underneath the bars. Bars are automatically suppressed if text becomes too large, so it is advisable to use a small font size here." ) );
   pageLayout->addWidget( mFontSize, 3, 1 );
   label->setBuddy( mFontSize );
@@ -357,8 +358,8 @@ void DancingBarsSettings::editSensor()
   SensorModelEntry sensor = mModel->sensor( index );
 
   bool ok;
-  const QString name = KInputDialog::getText( i18n( "Label of Bar Graph" ),
-                                              i18n( "Enter new label:" ), sensor.label(), &ok, this );
+  const QString name = QInputDialog::getText( this, i18n( "Label of Bar Graph" ),
+                                              i18n( "Enter new label:" ), QLineEdit::Normal, sensor.label(), &ok);
   if ( ok ) {
     sensor.setLabel( name );
     mModel->setSensor( sensor, index );
